<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:template name="hyperpool.bundle">
		<object class="java.lang.Class" method="forName">
			<string>vicazh.hyperpool.Reader</string>
			<void id="loader" method="getClassLoader"/>
		</object>
		<object id="bundle" class="java.util.ResourceBundle" method="getBundle">
			<string>vicazh.hyperpool.resources.application</string>
			<object class="java.util.Locale" method="getDefault"/>
			<object idref="loader"/>
		</object>
	</xsl:template>
	<xsl:template name="index">
		<xsl:value-of select="count(preceding::*)+count(ancestor::*)"/>
	</xsl:template>
	<xsl:template name="id">
		<xsl:attribute name="id">
			<xsl:call-template name="index"/>
		</xsl:attribute>
	</xsl:template>
	<xsl:template name="idref">
		<object id="service">
			<xsl:attribute name="idref">
				<xsl:call-template name="index"/>
			</xsl:attribute>
		</object>
	</xsl:template>
	<xsl:template match="group">
		<object class="vicazh.hyperpool.Group">
			<xsl:call-template name="id"/>
			<void property="name">
				<string>
					<xsl:value-of select="@name"/>
				</string>
			</void>
		</object>
		<xsl:call-template name="panel"/>
		<xsl:apply-templates/>
		<object idref="meditor">
			<void method="upGroup"/>
		</object>
	</xsl:template>
	<xsl:template match="line">
		<object class="vicazh.hyperpool.Line">
			<xsl:call-template name="id"/>
			<void property="name">
				<string>
					<xsl:value-of select="@name"/>
				</string>
			</void>
		</object>
		<xsl:call-template name="panel"/>
		<xsl:apply-templates/>
		<object idref="meditor">
			<void method="upLine"/>
		</object>
	</xsl:template>
	<xsl:template name="start">
		<xsl:for-each select="//*[name()!='group' and name()!='line' and (name(..)=name(/*) or name(..)='line')]">
			<object>
				<xsl:attribute name="idref">
					<xsl:call-template name="index"/>
				</xsl:attribute>
				<void method="start"/>
			</object>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="load">
		<java>
			<object class="vicazh.hyperpool.Start" field="SYSTEM_NAME">
				<void id="lowname" method="toLowerCase">
					<void id="namehome" method="concat">
						<string>.home</string>
					</void>
				</void>
			</object>
			<object class="java.lang.String">
				<string>.</string>
				<void id="dotname" method="concat">
					<object idref="lowname" />
					<void method="concat">
						<object class="java.io.File" field="separator" />
						<void id="nameuser" method="concat">
							<string>user</string>
						</void>
					</void>
				</void>
			</object>
			<object class="vicazh.hyperpool.Reader">
				<string>resources/user.xsl</string>
				<void id="user" method="getObject">
					<object id="fileuser" class="java.io.File">
						<object class="java.lang.System" method="getProperty">
							<string>user.home</string>
							<void method="concat">
								<object class="java.io.File" field="separator" />
								<void id="systemhome" method="concat">
									<object idref="dotname" />
								</void>
							</void>
						</object>
						<object idref="nameuser" />
					</object>
					<object class="vicazh.hyperpool.User">
						<void property="home">
							<object idref="systemhome" />
						</void>
					</object>
					<void method="setOut">
						<object class="vicazh.hyperpool.Writer">
							<string>resources/usersave.xsl</string>
						</object>
						<object idref="fileuser" />
					</void>
					<void id="valuehome" property="home" />
				</void>
			</object>
			<object class="java.lang.String">
				<string>.</string>
				<void method="concat">
					<object idref="lowname" />
					<void method="concat">
						<object class="java.io.File" field="separator" />
						<void id="nameuser" method="concat">
							<string>iuser</string>
						</void>
					</void>
				</void>
			</object>
			<object class="vicazh.hyperpool.Reader">
				<string>resources/iuser.xsl</string>
				<void id="iuser" method="getObject">
					<object id="fileuser" class="java.io.File">
						<object class="java.lang.System" method="getProperty">
							<string>user.home</string>
						</object>
						<object idref="nameuser" />
					</object>
					<object class="vicazh.hyperpool.IUser" />
				</void>
			</object>
			<xsl:call-template name="objects" />
			<object class="java.lang.Runtime" method="getRuntime">
				<void method="addShutdownHook">
					<object class="java.lang.Thread">
						<object idref="user" />
					</object>
				</void>
			</object>
			<object class="java.lang.System" method="setProperty">
				<object idref="namehome" />
				<object idref="valuehome" />
			</object>
			<object class="vicazh.hyperpool.Utils" method="clean">
				<string>hpa</string>
			</object>
			<void id="mreader" property="owner"/>
			<object class="vicazh.hyperpool.Com">
				<object id="meditor" class="vicazh.hyperpool.Editor">
					<object idref="mreader"/>
					<object id="ilist" class="java.util.ArrayList"/>
				</object>
				<object id="mwriter" class="vicazh.hyperpool.MWriter">
					<string>
						<xsl:call-template name="save"/>
					</string>
					<object idref="ilist"/>
				</object>
				<void method="start"/>
			</object>
			<void property="owner">
				<void property="parameter">
					<object class="java.util.ArrayList">
						<void method="add">
							<object idref="mwriter"/>
						</void>
						<void method="add">
							<object idref="meditor"/>
						</void>
					</object>
				</void>
			</void>
		</java>
	</xsl:template>
	<xsl:template name="project">
		<object class="vicazh.hyperpool.Project">
			<xsl:call-template name="id"/>
			<void property="name">
				<string>
					<xsl:value-of select="@name"/>
				</string>
			</void>
			<void property="version">
				<object class="vicazh.hyperpool.Start" field="VERSION"/>
			</void>
		</object>
		<xsl:call-template name="panel"/>
		<object idref="mwriter">
			<void property="object">
				<object idref="service"/>
			</void>			
		</object>
		<xsl:apply-templates/>
		<xsl:call-template name="start"/>
	</xsl:template>
	<xsl:template match="create">
		<java>
			<void property="owner">
				<void property="parameter">
					<void id="mwriter" index="0"/>
					<void id="meditor" index="1"/>
				</void>
			</void>
			<xsl:call-template name="project"/>
		</java>
	</xsl:template>
	<xsl:template match="hyperpool">
		<java>
			<void property="owner">
				<void property="parameter">
					<void id="mwriter" index="0"/>
					<void id="meditor" index="1"/>
				</void>
			</void>
			<xsl:call-template name="project"/>
		</java>
	</xsl:template>
	<xsl:template match="close">
		<java>
			<void property="owner">
				<void property="parameter">
					<void id="mwriter" index="0"/>
					<void id="meditor" index="1"/>
				</void>
			</void>
			<object idref="meditor">
				<void method="stop"/>
			</object>
			<object idref="mwriter">
				<void property="object">
					<null/>
				</void>			
			</object>
		</java>
	</xsl:template>
	<xsl:template match="add">
		<java>
			<void property="owner">
				<void property="parameter">
					<void id="meditor" index="1"/>
				</void>
			</void>
			<xsl:apply-templates/>
			<xsl:call-template name="start"/>
		</java>
	</xsl:template>
	<xsl:template name="panel">
		<xsl:call-template name="idref"/>
		<object idref="meditor">
			<void method="put">
				<object idref="service"/>
			</void>
		</object>
	</xsl:template>
	<xsl:template match="first">
		<java>
			<object class="vicazh.hyperpool.Start" field="SYSTEM_NAME">
				<void id="lowname" method="toLowerCase" />
			</object>
			<object class="java.lang.String">
				<string>.</string>
				<void method="concat">
					<object idref="lowname" />
					<void method="concat">
						<object class="java.io.File" field="separator" />
						<void id="namesave" method="concat">
							<string>save</string>
						</void>
					</void>
				</void>
			</object>
			<void property="owner">
				<void method="start">
					<object class="java.io.File">
						<object class="java.lang.System" method="getProperty">
							<string>user.home</string>
						</object>
						<object idref="namesave" />
					</object>
				</void>
			</void>
		</java>
	</xsl:template>
</xsl:stylesheet>
